<?php

namespace Drupal\vipps_mobilepay_commerce\EventSubscriber;

use Drupal\vipps_mobilepay_commerce\Event\InitiateCheckoutEvent;
use Drupal\vipps_mobilepay_commerce\Event\VippsMobilePayEvents;
use Drupal\vipps_mobilepay_commerce\Resolver\CommerceShippingMethodsResolver;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use zaporylie\Vipps\Model\Checkout\v3\Logistics;

/**
 * Adds shipping rates to the Vipps MobilePay checkout.
 */
class ShippingCheckoutEventSubscriber implements EventSubscriberInterface {

  /**
   * The subscriber constructor.
   *
   * @param \Drupal\vipps_mobilepay_commerce\Resolver\CommerceShippingMethodsResolver $resolver
   *   The resolver.
   */
  public function __construct(protected CommerceShippingMethodsResolver $resolver) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      VippsMobilePayEvents::INITIATE_CHECKOUT => ['onShipping'],
    ];
  }

  /**
   * Adds shipping rates to the request.
   *
   * @param \Drupal\vipps_mobilepay_commerce\Event\InitiateCheckoutEvent $event
   *   The checkout initiation event.
   */
  public function onShipping(InitiateCheckoutEvent $event) {
    $request = $event->getRequest();
    $logistics = new Logistics();
    $options = $this->resolver->resolve($event->getPayment()->getOrder());
    $logistics->setFixedOptions($options);
    $request->setLogistics($logistics);
  }

}
